@@ -1,19 +1,26 @@
 import json
 import random
 import os.path
+import requests
 
 from IPython.display import HTML, Javascript, display
 from .file_reader import register_filecomm
 from .svg import register_svgcomm
 
-def init():
+_igv_version = None
 
+def init(version = None):
+    global _igv_version
     register_filecomm()
     register_svgcomm()
 
-    igv_filepath = os.path.join(os.path.dirname(__file__), 'js/igv.min.js')
-    igv_file = open(igv_filepath, 'r')
-    igv_js = igv_file.read()
+    if version is None:
+        igv_filepath = os.path.join(os.path.dirname(__file__), 'js/igv.min.js')
+        igv_file = open(igv_filepath, 'r')
+        igv_js = igv_file.read()
+    else:
+        _igv_version = version
+        igv_js = download_igv(version)
     display(Javascript(igv_js))
 
     message_filepath = os.path.join(os.path.dirname(__file__), 'js/messageHandler.js')
@@ -26,6 +33,13 @@ def init():
     nb_js = nbfile.read()
     display(Javascript(nb_js))
 
+def igv_version():
+    global _igv_version
+    if _igv_version is None:
+        with open('../VERSION_IGV') as version_file:
+            _igv_version = version_file.read().strip()
+    return _igv_version
+
 
 class Browser(object):
 
@@ -58,7 +72,7 @@ class Browser(object):
         """
         Load a track.  Corresponds to the igv.js Browser function loadTrack (see https://github.com/igvteam/igv.js/wiki/Browser-Control-2.0#loadtrack).
 
-        :param  track: A dictionary specifying track options.  See https://github.com/igvteam/igv.js/wiki/Tracks-2.0.
+        :param  config: A dictionary specifying track options.  See https://github.com/igvteam/igv.js/wiki/Tracks-2.0.
         :type dict
         """
 
@@ -67,7 +81,7 @@ class Browser(object):
             if isinstance(config, str):
                 config = {"url": config}
             else:
-                raise Exception("load_track parameter must be a dictionary or string")
+                raise Exception("load_track parameter must be a dictionary or url (string) to a track data file")
 
         self._send({
             "id": self.igv_id,
@@ -75,6 +89,34 @@ class Browser(object):
             "data": config
         })
 
+    def load_roi(self, config):
+        """
+        Load regions of interest.  Corresponds to the igv.js Browser function loadROI (see https://github.com/igvteam/igv.js/wiki/Browser-API-2.0#loadroiconfigorarray).
+
+        :param  config: A dictionary specifying a set of ROIs as a track of type 'annotation'.  See https://github.com/igvteam/igv.js/wiki/Tracks-2.0.
+        :type dict
+        """
+
+        # Check for minimal requirements
+        if isinstance(config, dict) == False and isinstance(config, list) == False:
+            if isinstance(config, str):
+                config = {"url": config}
+            else:
+                raise Exception("load_track parameter must be a dictionary, list of dictionaries, or url (string) to an annotation file")
+
+        self._send({
+            "id": self.igv_id,
+            "command": "loadROI",
+            "data": config
+        })
+
+    def clear_rois(self):
+        self._send({
+            "id": self.igv_id,
+            "command": "clearROIs"
+        })
+
+
     def search(self, locus):
         """
         Go to the specified locus.
@@ -123,3 +165,17 @@ class Browser(object):
 
     def _gen_id(self):
         return 'jb_' + str(random.randint(1, 10000000))
+
+
+def download_igv(version):
+
+    remote_url = "https://cdn.jsdelivr.net/npm/igv@" + version + "/dist/igv.min.js"
+
+    igvjs = requests.get(remote_url)
+
+    # Replace the UMD magic with a window global definition.  The UMD header is produced by rollup, this might need to be
+    # modified if rollup changes, but the basic idea is to assign the value returned by the factory function to "window.igv".
+    return igvjs.text.replace(
+        'function(t,e){"object"==typeof exports&&"undefined"!=typeof module?module.exports=e():"function"==typeof define&&define.amd?define(e):(t="undefined"!=typeof globalThis?globalThis:t||self).igv=e()}',
+        'function (global, factory) {window.igv = factory()}', 1)
+
